@@ -34,7 +34,7 @@ EasyBuild support for BiSearch, implemented as an easyblock
 import os
 
 from easybuild.framework.easyblock import EasyBlock
-from easybuild.tools.filetools import run_cmd_qa
+from easybuild.tools.run import run_cmd_qa
 
 
 class EB_BiSearch(EasyBlock):
