@@ -34,7 +34,7 @@ import shutil
 from easybuild.framework.easyconfig import CUSTOM
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.tools.modules import get_software_root, get_software_version
-from easybuild.tools.filetools import run_cmd
+from easybuild.tools.run import run_cmd
 import easybuild.tools.toolchain as toolchain
 
 # Possible systemsizes for CHARMM
