@@ -37,8 +37,8 @@ import os
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.framework.easyconfig import CUSTOM
 from easybuild.tools.environment import setvar
-from easybuild.tools.filetools import run_cmd
 from easybuild.tools.modules import ROOT_ENV_VAR_NAME_PREFIX
+from easybuild.tools.run import run_cmd
 
 
 class CMakeMake(ConfigureMake):
@@ -47,12 +47,12 @@ class CMakeMake(ConfigureMake):
     @staticmethod
     def extra_options(extra_vars=None):
         """Define extra easyconfig parameters specific to CMakeMake."""
-        extra_vars = dict(ConfigureMake.extra_options(extra_vars))
+        extra_vars = ConfigureMake.extra_options(extra_vars)
         extra_vars.update({
             'srcdir': [None, "Source directory location to provide to cmake command", CUSTOM],
             'separate_build_dir': [False, "Perform build in a separate directory", CUSTOM],
         })
-        return ConfigureMake.extra_options(extra_vars)
+        return extra_vars
 
     def configure_step(self, srcdir=None, builddir=None):
         """Configure build using cmake"""
