@@ -42,7 +42,8 @@ import glob
 import easybuild.tools.environment as env
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM
-from easybuild.tools.filetools import rmtree2, run_cmd
+from easybuild.tools.filetools import rmtree2
+from easybuild.tools.run import run_cmd
 
 # required for deprecated log in static function (ie no self)
 from easybuild.framework.easyconfig.licenses import License
@@ -96,9 +97,12 @@ class IntelBase(EasyBlock):
         self.setup_local_home_subdir()
         self.clean_home_subdir()
 
+        if self.cfg._config['license'][0] is not None:
+            _log.deprecated('No old style license parameter, use license_file', '2.0')
+
     @staticmethod
     def extra_options(extra_vars=None):
-        extra_vars = dict(EasyBlock.extra_options(extra_vars))
+        extra_vars = EasyBlock.extra_options(extra_vars)
         extra_vars.update({
             'license_activation': [ACTIVATION_LIC_SERVER, "License activation type", CUSTOM],
             # 'usetmppath':
@@ -110,10 +114,9 @@ class IntelBase(EasyBlock):
         })
 
         # Support for old easyconfigs with license parameter
-        _log.deprecated('No old style license parameter, use license_file', '2.0')
-        extra_vars.update({'license': [None, "License file", CUSTOM]})
+        extra_vars.update({'license': [None, "License file (DEPRECATED, use 'license_file' instead)", CUSTOM]})
 
-        return EasyBlock.extra_options(extra_vars)
+        return extra_vars
 
     def clean_home_subdir(self):
         """Remove contents of (local) 'intel' directory home subdir, where stuff is cached."""
@@ -343,6 +346,27 @@ class IntelBase(EasyBlock):
         cmd = "./install.sh %s -s %s" % (tmppathopt, silentcfg)
         return run_cmd(cmd, log_all=True, simple=True)
 
+    def move_after_install(self):
+        """Move installed files to correct location after installation."""
+        subdir = os.path.join(self.installdir, self.name, self.version)
+        self.log.debug("Moving contents of %s to %s" % (subdir, self.installdir))
+        try:
+            # remove senseless symlinks, e.g. impi_5.0.1 and impi_latest
+            majver = '.'.join(self.version.split('.')[:-1])
+            for symlink in ['%s_%s' % (self.name, majver), '%s_latest' % self.name]:
+                symlink_fp = os.path.join(self.installdir, symlink)
+                if os.path.exists(symlink_fp):
+                    os.remove(symlink_fp)
+            # move contents of 'impi/<version>' dir to installdir
+            for fil in os.listdir(subdir):
+                source = os.path.join(subdir, fil)
+                target = os.path.join(self.installdir, fil)
+                self.log.debug("Moving %s to %s" % (source, target))
+                shutil.move(source, target)
+            shutil.rmtree(os.path.join(self.installdir, self.name))
+        except OSError, err:
+            self.log.error("Failed to move contents of %s to %s: %s" % (subdir, self.installdir, err))
+
     def cleanup_step(self):
         """Cleanup leftover mess
 
