@@ -37,7 +37,7 @@ import re
 from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.intelbase import IntelBase, ACTIVATION_NAME_2012, LICENSE_FILE_NAME_2012
-from easybuild.tools.filetools import run_cmd
+from easybuild.tools.run import run_cmd
 
 
 def get_icc_version():
@@ -158,10 +158,7 @@ class EB_icc(IntelBase):
 
     def make_module_extra(self):
         """Add extra environment variables for icc, for license file and NLS path."""
-
         txt = super(EB_icc, self).make_module_extra()
-
-        txt += "prepend-path\t%s\t\t%s\n" % (self.license_env_var, self.license_file)
-        txt += "prepend-path\t%s\t\t$root/%s\n" % ('NLSPATH', 'idb/intel64/locale/%l_%t/%N')
-
+        txt += self.module_generator.prepend_paths(self.license_env_var, [self.license_file], allow_abs=True)
+        txt += self.module_generator.prepend_paths('NLSPATH', '$root/idb/intel64/locale/%l_%t/%N')
         return txt
