@@ -39,7 +39,7 @@ import sys
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.easyblocks.perl import get_major_perl_version
-from easybuild.tools.filetools import run_cmd
+from easybuild.tools.run import run_cmd
 
 
 class EB_MUMmer(ConfigureMake):
@@ -103,9 +103,9 @@ class EB_MUMmer(ConfigureMake):
 
         # set $PATH and $PERLXLIB correctly
         txt = super(EB_MUMmer, self).make_module_extra()
-        txt += self.moduleGenerator.prepend_paths("PATH", ['bin'])
-        txt += self.moduleGenerator.prepend_paths("PATH", ['bin/aux_bin'])
-        txt += self.moduleGenerator.prepend_paths("PERL%sLIB" % perlmajver, ['bin/scripts'])
+        txt += self.module_generator.prepend_paths("PATH", ['bin'])
+        txt += self.module_generator.prepend_paths("PATH", ['bin/aux_bin'])
+        txt += self.module_generator.prepend_paths("PERL%sLIB" % perlmajver, ['bin/scripts'])
         return txt
 
     def sanity_check_step(self):
