@@ -40,8 +40,9 @@ from distutils.version import LooseVersion
 import easybuild.tools.environment as env
 import easybuild.tools.toolchain as toolchain
 from easybuild.framework.easyblock import EasyBlock
-from easybuild.tools.filetools import adjust_permissions, mkdir, run_cmd, run_cmd_qa
+from easybuild.tools.filetools import adjust_permissions, mkdir
 from easybuild.tools.modules import get_software_root
+from easybuild.tools.run import run_cmd, run_cmd_qa
 
 
 class EB_OpenFOAM(EasyBlock):
@@ -160,12 +161,15 @@ class EB_OpenFOAM(EasyBlock):
                 "Proceed without compiling cudaSolvers? [Y/n]": 'Y',
             }
             noqa = [
-                ".* -o .*\.o",
+                ".* -o .*",
                 "checking .*",
                 "warning.*",
                 "configure: creating.*",
                 "%s .*" % os.environ['CC'],
                 "wmake .*",
+                "Making dependency list for source file.*",
+                "\s*\^\s*",  # warning indicator
+                "Cleaning .*",
             ]
             run_cmd_qa(cmd_tmpl % 'Allwmake.firstInstall', qa, no_qa=noqa, log_all=True, simple=True)
         else:
@@ -247,6 +251,6 @@ class EB_OpenFOAM(EasyBlock):
         ]
 
         for (env_var, val) in env_vars:
-            txt += self.moduleGenerator.set_environment(env_var, val)
+            txt += self.module_generator.set_environment(env_var, val)
 
         return txt
