@@ -37,8 +37,9 @@ import shutil
 import tempfile
 
 from easybuild.easyblocks.generic.pythonpackage import PythonPackage
-from easybuild.tools.filetools import extract_file, rmtree2, run_cmd
+from easybuild.tools.filetools import extract_file, rmtree2
 from easybuild.tools.modules import get_software_root
+from easybuild.tools.run import run_cmd
 
 
 class EB_python_minus_meep(PythonPackage):
