@@ -44,8 +44,9 @@ import easybuild.tools.toolchain as toolchain
 from easybuild.easyblocks.netcdf import set_netcdf_env_vars, get_netcdf_module_set_cmds  #@UnresolvedImport
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM, MANDATORY
-from easybuild.tools.filetools import extract_file, patch_perl_script_autoflush, rmtree2, run_cmd, run_cmd_qa
+from easybuild.tools.filetools import extract_file, patch_perl_script_autoflush, rmtree2
 from easybuild.tools.modules import get_software_root, get_software_version
+from easybuild.tools.run import run_cmd, run_cmd_qa
 
 
 class EB_WPS(EasyBlock):
